/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.event;

import java.io.Serializable;

import org.tinygroup.context.Context;

/**
 * 服务请求
 * 
 * @author luoguo
 * 
 * @param <Service>
 */
public final class ServiceRequest implements Serializable {

	private static final long serialVersionUID = 5231646457246478802L;
	transient String fullServiceName;
	/**
	 * 节点名称，如果有指定节点名称，则只能访问指定节点上的服务
	 */
	String nodeName;
	/**
	 * 组织标识
	 */
	private String groupId;
	/**
	 * 模块标识
	 */
	private String artifactId;
	/**
	 * 服务名称
	 */
	private String name;
	/**
	 * 服务标识
	 */
	private String serviceId;
	/**
	 * 版本
	 */
	private String version;
	/**
	 * 服务请求所带的参数
	 */
	private Context context;

	public String getNodeName() {
		return nodeName;
	}

	public void setNodeName(String nodeName) {
		this.nodeName = nodeName;
	}

	public Context getContext() {
		return context;
	}

	public void setContext(Context context) {
		this.context = context;
	}

	public String getGroupId() {
		return groupId;
	}

	public void setGroupId(String groupId) {
		this.groupId = groupId;
	}

	public String getArtifactId() {
		return artifactId;
	}

	public void setArtifactId(String artifactId) {
		this.artifactId = artifactId;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getServiceId() {
		return serviceId;
	}

	public void setServiceId(String serviceId) {
		this.serviceId = serviceId;
	}

	public String getVersion() {
		return version;
	}

	public void setVersion(String version) {
		this.version = version;
	}

	public String getFullServiceName() {
		if (fullServiceName == null) {
			fullServiceName = String.format("%s.%s.%s", groupId, artifactId,
					name);
		}
		return fullServiceName;
	}
}